##  Overview
You can use SAP discovery to link SAP Build projects to new or existing fact sheets in SAP LeanIX. Using [SAP Build Process Automation![Information published on SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/sap_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fdiscovery-center.cloud.sap%2FserviceCatalog%2Fsap-build-process-automation%3Fregion%3Dall "https://discovery-center.cloud.sap/serviceCatalog/sap-build-process-automation?region=all") as a gateway, you can connect SAP LeanIX workspaces to SAP Build instances and their components in the SAP Business Technology Platform (SAP BTP), including SAP Build Apps, SAP Build Code, and SAP Build Process Automation. Once connected, the SAP discovery feature also retrieves contextual information from the [SAP Cloud Management Service![Information published on SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/sap_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fdiscovery-center.cloud.sap%2FserviceCatalog%2Fcloud-management-service%3Fregion%3Dall "https://discovery-center.cloud.sap/serviceCatalog/cloud-management-service?region=all") for SAP BTP.
